summaryrefslogtreecommitdiff
path: root/starmath/source/visitors.cxx
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2021-02-04 10:16:38 +0100
committerAndrea Gelmini <andrea.gelmini@gelma.net>2021-02-04 17:11:57 +0100
commite3ea88c6db5facde01ad0c46d8f9393c4db08c5c (patch)
tree591458fb88e9b09ea7fb196e2ea2e0cb6a74b92b /starmath/source/visitors.cxx
parente1d7242341ec148b631a96e6d63697bce6a497c9 (diff)
Fix typo in code
Here it passed "make build-nocheck" on Linux Change-Id: I1f6ea440e54f87a90abb1b6e9983443764516e06 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/110373 Reviewed-by: Julien Nabet <serval2412@yahoo.fr> Reviewed-by: Dante DM <dante19031999@gmail.com> Reviewed-by: Andrea Gelmini <andrea.gelmini@gelma.net> Tested-by: Jenkins
Diffstat (limited to 'starmath/source/visitors.cxx')
-rw-r--r--starmath/source/visitors.cxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/starmath/source/visitors.cxx b/starmath/source/visitors.cxx
index 3de2d3106322..8d72859c6b7b 100644
--- a/starmath/source/visitors.cxx
+++ b/starmath/source/visitors.cxx
@@ -44,7 +44,7 @@ void SmDefaultingVisitor::Visit( SmAlignNode* pNode )
DefaultVisit( pNode );
}
-void SmDefaultingVisitor::Visit( SmAttributNode* pNode )
+void SmDefaultingVisitor::Visit( SmAttributeNode* pNode )
{
DefaultVisit( pNode );
}
@@ -297,7 +297,7 @@ void SmDrawingVisitor::Visit( SmAlignNode* pNode )
DrawChildren( pNode );
}
-void SmDrawingVisitor::Visit( SmAttributNode* pNode )
+void SmDrawingVisitor::Visit( SmAttributeNode* pNode )
{
DrawChildren( pNode );
}
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( SmBraceNode* pNode )
mpRightMost = right;
}
/** Build SmCaretPosGraph for SmAttributNode
*
* Lines in an SmAttributNode:
* \code
* Attr
* Body
* \endcode
*
* There's a body and an attribute, the construction is used for "widehat A", where "A" is the body
* and "^" is the attribute ( note GetScaleMode( ) on SmAttributNode tells how the attribute should be
* scaled ).
*/
-void SmCaretPosGraphBuildingVisitor::Visit( SmAttributNode* pNode )
+void SmCaretPosGraphBuildingVisitor::Visit( SmAttributeNode* pNode )
{
SmNode *pAttr = pNode->Attribute(),
*pBody = pNode->Body();
@@ -1671,9 +1671,9 @@ void SmCloningVisitor::Visit( SmAlignNode* pNode )
mpResult = pClone;
}
-void SmCloningVisitor::Visit( SmAttributNode* pNode )
+void SmCloningVisitor::Visit( SmAttributeNode* pNode )
{
- SmAttributNode* pClone = new SmAttributNode( pNode->GetToken( ) );
+ SmAttributeNode* pClone = new SmAttributeNode( pNode->GetToken( ) );
CloneNodeAttr( pNode, pClone );
CloneKids( pNode, pClone );
mpResult = pClone;
@@ -2078,7 +2078,7 @@ void SmNodeToTextVisitor::Visit( SmAlignNode* pNode )
LineToText( pNode->GetSubNode( 0 ) );
}
-void SmNodeToTextVisitor::Visit( SmAttributNode* pNode )
+void SmNodeToTextVisitor::Visit( SmAttributeNode* pNode )
{
Append( pNode->GetToken( ).aText );
LineToText( pNode->Body() );
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( SmBraceNode* pNode )
mpRightMost = right;
}
-/** Build SmCaretPosGraph for SmAttributNode
+/** Build SmCaretPosGraph for SmAttributeNode
*
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( SmBraceNode* pNode )
*
- * Lines in an SmAttributNode:
+ * Lines in an SmAttributeNode:
* \code
* Attr
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( SmBraceNode* pNode )
*
* There's a body and an attribute, the construction is used for "widehat A", where "A" is the body
- * and "^" is the attribute ( note GetScaleMode( ) on SmAttributNode tells how the attribute should be
+ * and "^" is the attribute ( note GetScaleMode( ) on SmAttributeNode tells how the attribute should be
* scaled ).
*/